[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[elpa] externals/ef-themes 2100944044 1/3: Update theme one-line descrip
From: |
ELPA Syncer |
Subject: |
[elpa] externals/ef-themes 2100944044 1/3: Update theme one-line descriptions |
Date: |
Tue, 6 Sep 2022 11:57:35 -0400 (EDT) |
branch: externals/ef-themes
commit 2100944044a2cc7e8fbf59cf15a18b896d1f2a78
Author: Protesilaos Stavrou <info@protesilaos.com>
Commit: Protesilaos Stavrou <info@protesilaos.com>
Update theme one-line descriptions
Thanks to Philip Kaludercic for reminding me about it:
<https://lists.sr.ht/~protesilaos/ef-themes/%3C87leqwftyp.fsf%40posteo.net%3E>.
---
ef-autumn-theme.el | 4 ++--
ef-dark-theme.el | 4 ++--
ef-day-theme.el | 4 ++--
ef-duo-dark-theme.el | 4 ++--
ef-duo-light-theme.el | 4 ++--
ef-light-theme.el | 4 ++--
ef-night-theme.el | 4 ++--
ef-spring-theme.el | 4 ++--
ef-summer-theme.el | 4 ++--
ef-winter-theme.el | 4 ++--
10 files changed, 20 insertions(+), 20 deletions(-)
diff --git a/ef-autumn-theme.el b/ef-autumn-theme.el
index 4183d3215a..adefb255a4 100644
--- a/ef-autumn-theme.el
+++ b/ef-autumn-theme.el
@@ -1,4 +1,4 @@
;;; ef-autumn-theme.el --- Legible dark theme -*- lexical-binding:t -*-
lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
@@ -37,7 +37,7 @@
(eval-and-compile
(require 'ef-themes)
- (deftheme ef-autumn "Legible dark theme.")
+ (deftheme ef-autumn "Legible dark theme with warm colors.")
(defconst ef-autumn-palette
'(;; Basic tones
@@ -1,4 +1,4 @@
-;;; ef-autumn-theme.el --- Legible dark theme -*- lexical-binding:t -*-
+;;; ef-autumn-theme.el --- Legible dark theme with warm colors -*-
lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
diff --git a/ef-dark-theme.el b/ef-dark-theme.el
index fbb04c4259..8fd3cb9855 100644
--- a/ef-dark-theme.el
+++ b/ef-dark-theme.el
@@ -1,4 +1,4 @@
;;; ef-dark-theme.el --- Legible dark theme -*- lexical-binding:t -*-
lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
@@ -37,7 +37,7 @@
(eval-and-compile
(require 'ef-themes)
- (deftheme ef-dark "Legible dark theme.")
+ (deftheme ef-dark "Legible dark theme with blue and magenta colors.")
(defconst ef-dark-palette
'(;; Basic tones
@@ -1,4 +1,4 @@
-;;; ef-dark-theme.el --- Legible dark theme -*- lexical-binding:t -*-
+;;; ef-dark-theme.el --- Legible dark theme with blue and magenta colors -*-
lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
diff --git a/ef-day-theme.el b/ef-day-theme.el
index bf6ad163df..4be5195bf0 100644
--- a/ef-day-theme.el
+++ b/ef-day-theme.el
@@ -1,4 +1,4 @@
;;; ef-day-theme.el --- Legible light theme -*- lexical-binding:t -*-
lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
@@ -37,7 +37,7 @@
(eval-and-compile
(require 'ef-themes)
- (deftheme ef-day "Legible light theme.")
+ (deftheme ef-day "Legible light theme with warm colors.")
(defconst ef-day-palette
'(;; Basic tones
@@ -1,4 +1,4 @@
-;;; ef-day-theme.el --- Legible light theme -*- lexical-binding:t -*-
+;;; ef-day-theme.el --- Legible light theme with warm colors -*-
lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
diff --git a/ef-duo-dark-theme.el b/ef-duo-dark-theme.el
index c9983637f7..8861ac15d7 100644
--- a/ef-duo-dark-theme.el
+++ b/ef-duo-dark-theme.el
@@ -1,4 +1,4 @@
;;; ef-duo-dark-theme.el --- Legible dark theme -*- lexical-binding:t -*-
*- lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
@@ -40,7 +40,7 @@
;; Most of the colors here are defined simply to preserve
;; compatibility with the rest of the project. We don't actually rely
;; on them for anything critical.
- (deftheme ef-duo-dark "Legible dark theme.")
+ (deftheme ef-duo-dark "Legible dark theme with blue and yellow colors.")
(defconst ef-duo-dark-palette
'(;; Basic tones
@@ -1,4 +1,4 @@
-;;; ef-duo-dark-theme.el --- Legible dark theme -*- lexical-binding:t -*-
+;;; ef-duo-dark-theme.el --- Legible dark theme with blue and yellow colors
-*- lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
diff --git a/ef-duo-light-theme.el b/ef-duo-light-theme.el
index b10873e61b..79478a42bc 100644
--- a/ef-duo-light-theme.el
+++ b/ef-duo-light-theme.el
@@ -1,4 +1,4 @@
;;; ef-duo-light-theme.el --- Legible light theme -*- lexical-binding:t -*-
*- lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
@@ -40,7 +40,7 @@
;; Most of the colors here are defined simply to preserve
;; compatibility with the rest of the project. We don't actually rely
;; on them for anything critical.
- (deftheme ef-duo-light "Legible light theme.")
+ (deftheme ef-duo-light "Legible light theme with blue and yellow colors.")
(defconst ef-duo-light-palette
'(;; Basic tones
@@ -1,4 +1,4 @@
-;;; ef-duo-light-theme.el --- Legible light theme -*- lexical-binding:t -*-
+;;; ef-duo-light-theme.el --- Legible light theme with blue and yellow colors
-*- lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
diff --git a/ef-light-theme.el b/ef-light-theme.el
index 27a72c7c14..bff1d83ea5 100644
--- a/ef-light-theme.el
+++ b/ef-light-theme.el
@@ -1,4 +1,4 @@
;;; ef-light-theme.el --- Legible light theme -*- lexical-binding:t -*-
lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
@@ -37,7 +37,7 @@
(eval-and-compile
(require 'ef-themes)
- (deftheme ef-light "Legible light theme.")
+ (deftheme ef-light "Legible light theme with blue and magenta colors.")
(defconst ef-light-palette
'(;; Basic tones
@@ -1,4 +1,4 @@
-;;; ef-light-theme.el --- Legible light theme -*- lexical-binding:t -*-
+;;; ef-light-theme.el --- Legible light theme with blue and magenta colors -*-
lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
diff --git a/ef-night-theme.el b/ef-night-theme.el
index 6bd0d41da3..bb9727dee7 100644
--- a/ef-night-theme.el
+++ b/ef-night-theme.el
@@ -1,4 +1,4 @@
;;; ef-night-theme.el --- Legible dark theme -*- lexical-binding:t -*-
lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
@@ -37,7 +37,7 @@
(eval-and-compile
(require 'ef-themes)
- (deftheme ef-night "Legible dark theme.")
+ (deftheme ef-night "Legible dark theme with cool colors.")
(defconst ef-night-palette
'(;; Basic tones
@@ -1,4 +1,4 @@
-;;; ef-night-theme.el --- Legible dark theme -*- lexical-binding:t -*-
+;;; ef-night-theme.el --- Legible dark theme with cool colors -*-
lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
diff --git a/ef-spring-theme.el b/ef-spring-theme.el
index 475cf8faed..a4877d29dc 100644
--- a/ef-spring-theme.el
+++ b/ef-spring-theme.el
@@ -1,4 +1,4 @@
;;; ef-spring-theme.el --- Legible light theme -*- lexical-binding:t -*-
*- lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
@@ -37,7 +37,7 @@
(eval-and-compile
(require 'ef-themes)
- (deftheme ef-spring "Legible light theme.")
+ (deftheme ef-spring "Legible light theme with cool, green, red colors.")
(defconst ef-spring-palette
'(;; Basic tones
@@ -1,4 +1,4 @@
-;;; ef-spring-theme.el --- Legible light theme -*- lexical-binding:t -*-
+;;; ef-spring-theme.el --- Legible light theme with cool, green, red colors
-*- lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
diff --git a/ef-summer-theme.el b/ef-summer-theme.el
index cfa850d5d6..44c6bb8b73 100644
--- a/ef-summer-theme.el
+++ b/ef-summer-theme.el
@@ -1,4 +1,4 @@
;;; ef-summer-theme.el --- Legible light theme -*- lexical-binding:t -*-
colors -*- lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
@@ -37,7 +37,7 @@
(eval-and-compile
(require 'ef-themes)
- (deftheme ef-summer "Legible light theme.")
+ (deftheme ef-summer "Legible light theme with magenta, purple, gold colors.")
(defconst ef-summer-palette
'(;; Basic tones
@@ -1,4 +1,4 @@
-;;; ef-summer-theme.el --- Legible light theme -*- lexical-binding:t -*-
+;;; ef-summer-theme.el --- Legible light theme with magenta, purple, gold
colors -*- lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
diff --git a/ef-winter-theme.el b/ef-winter-theme.el
index 312f5b9d3d..2e515842e7 100644
--- a/ef-winter-theme.el
+++ b/ef-winter-theme.el
@@ -1,4 +1,4 @@
;;; ef-winter-theme.el --- Legible dark theme -*- lexical-binding:t -*-
colors -*- lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.
@@ -37,7 +37,7 @@
(eval-and-compile
(require 'ef-themes)
- (deftheme ef-winter "Legible dark theme.")
+ (deftheme ef-winter "Legible dark theme with magenta, purple, gold colors.")
(defconst ef-winter-palette
'(;; Basic tones
@@ -1,4 +1,4 @@
-;;; ef-winter-theme.el --- Legible dark theme -*- lexical-binding:t -*-
+;;; ef-winter-theme.el --- Legible dark theme with magenta, purple, gold
colors -*- lexical-binding:t -*-
;; Copyright (C) 2022 Free Software Foundation, Inc.